@@ -12,8 +12,8 @@ def instrument_MySQLdb(module):
             return callback
         
         return trace
-    
-    module.connect = wrapper(module.connect)
+    if hasattr(module, "connect"):
+        module.connect = wrapper(module.connect)
     
     def wrapper(fn):
         @trace_handler(fn)
@@ -23,8 +23,9 @@ def instrument_MySQLdb(module):
         
         return trace
     
-    get_dict(module.connection)['close'] = wrapper(
-        module.connection.close)
+    if hasattr(module, "connection") and hasattr(module.connection, "close"):
+        get_dict(module.connection)['close'] = wrapper(
+            module.connection.close)
 
 
 def instrument_MySQLdb_cursors(module):
