@@ -36,6 +36,8 @@ DEFINITION = {
     'database_toolkit': [
         ('sqlalchemy.orm.session', 'instrument_sqlalchemy'),
         ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
+        ('sqlalchemy.engine.create', 'instrument_sqlalchemy_engine_basic'),
+        ('sqlalchemy.engine', 'instrument_sqlalchemy_engine_basic'),
     ],
     'application_wsgi': [
         ('', ''),
@@ -78,9 +80,9 @@ DEFINITION = {
     'database_redis':[
         ('redis','instrument_redis_connection'),
     ],
-    # 'email_smtp':[
-    #     ('smtplib','instrument_smtp'),
-    # ],
+    'email_smtp':[
+        ('smtplib','instrument_smtp'),
+    ],
     # 'amqp_kombu':[
     #     ('kombu','instrument_kombu'),
     # ],
@@ -91,5 +93,8 @@ DEFINITION = {
         ('nameko.containers', 'instrument_nameko_spawn_worker'),
         ('spsengine.containers', 'instrument_nameko_spawn_worker'),
     ],
-
+    'application_graphql':[
+        #('graphql','instrument_graphql'),
+        ('graphql.execution.executor','instrument_graphql'),
+    ],
 }
